# coding: utf-8

"""
    World News API

    The world's news wrapped into a single API.

    The version of the OpenAPI document: 1.2.0
    Contact: mail@worldnewsapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import unittest

from worldnewsapi.models.get_geo_coordinates200_response import GetGeoCoordinates200Response


class TestGetGeoCoordinates200Response(unittest.TestCase):
    """GetGeoCoordinates200Response unit test stubs"""
    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetGeoCoordinates200Response:
        """Test GetGeoCoordinates200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetGeoCoordinates200Response`
        """
        model = GetGeoCoordinates200Response()
        if include_optional:
            return GetGeoCoordinates200Response(
                latitude = 1.337,
                longitude = 1.337,
                city = ''
            )
        else:
            return GetGeoCoordinates200Response(
        )
        """

    def testGetGeoCoordinates200Response(self):
        """Test GetGeoCoordinates200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
