# coding: utf-8

# flake8: noqa

"""
    World News API

    The world's news wrapped into a single API.

    The version of the OpenAPI document: 1.2.0
    Contact: mail@worldnewsapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.2.0"

# import apis into sdk package
from worldnewsapi.api.news_api import NewsApi

# import ApiClient
from worldnewsapi.api_response import ApiResponse
from worldnewsapi.api_client import ApiClient
from worldnewsapi.configuration import Configuration
from worldnewsapi.exceptions import OpenApiException
from worldnewsapi.exceptions import ApiTypeError
from worldnewsapi.exceptions import ApiValueError
from worldnewsapi.exceptions import ApiKeyError
from worldnewsapi.exceptions import ApiAttributeError
from worldnewsapi.exceptions import ApiException

# import models into sdk package
from worldnewsapi.models.extract_news200_response import ExtractNews200Response
from worldnewsapi.models.extract_news200_response_images_inner import ExtractNews200ResponseImagesInner
from worldnewsapi.models.extract_news200_response_videos_inner import ExtractNews200ResponseVideosInner
from worldnewsapi.models.extract_news_links200_response import ExtractNewsLinks200Response
from worldnewsapi.models.get_geo_coordinates200_response import GetGeoCoordinates200Response
from worldnewsapi.models.retrieve_news_articles_by_ids200_response import RetrieveNewsArticlesByIds200Response
from worldnewsapi.models.retrieve_news_articles_by_ids200_response_news_inner import RetrieveNewsArticlesByIds200ResponseNewsInner
from worldnewsapi.models.search_news200_response import SearchNews200Response
from worldnewsapi.models.search_news200_response_news_inner import SearchNews200ResponseNewsInner
from worldnewsapi.models.top_news200_response import TopNews200Response
from worldnewsapi.models.top_news200_response_top_news_inner import TopNews200ResponseTopNewsInner
from worldnewsapi.models.top_news200_response_top_news_inner_news_inner import TopNews200ResponseTopNewsInnerNewsInner
